@@ -43,6 +43,13 @@
 #include <windows.h>
 #endif
 
+#ifndef O_BINARY
+#ifdef _O_BINARY
+#define O_BINARY	_O_BINARY
+#else
+#define O_BINARY	0
+#endif
+#endif
 
 /* Report an unexpected error in GPGME and quit the application.  */
 void
@@ -130,8 +137,8 @@ check_overwriting (const char *filename, GtkWidget *parent)
 	 _("The file %s already exists.\n"
 	   "Do you want to overwrite it?"), filename);
       gtk_dialog_add_buttons (GTK_DIALOG (msgbox),
-			      GTK_STOCK_YES, GTK_RESPONSE_YES,
-			      GTK_STOCK_NO, GTK_RESPONSE_NO, NULL);
+			      _("_Yes"), GTK_RESPONSE_YES,
+			      _("_No"), GTK_RESPONSE_NO, NULL);
       if (gtk_dialog_run (GTK_DIALOG (msgbox)) == GTK_RESPONSE_NO)
 	{
 	  gtk_widget_destroy (msgbox);
@@ -176,7 +183,7 @@ gpa_open_output (const char *filename, gpgme_data_t *data, GtkWidget *parent)
     {
       gpg_error_t err;
 
-      target = creat (filename, 0666);
+      target = open (filename, O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0666);
       if (target == -1)
 	{
 	  gchar *message;
@@ -202,7 +209,7 @@ gpa_open_input (const char *filename, gpgme_data_t *data, GtkWidget *parent)
   gpg_error_t err;
   int target = -1;
 
-  target = open (filename, O_RDONLY);
+  target = open (filename, O_RDONLY | O_BINARY);
   if (target == -1)
     {
       gchar *message;
@@ -642,7 +649,7 @@ gpa_passphrase_cb (void *hook, const char *uid_hint,
 					NULL, GTK_DIALOG_MODAL,
 					GTK_STOCK_OK,
 					GTK_RESPONSE_OK,
-                                            GTK_STOCK_CANCEL,
+                                        _("_Cancel"),
 					GTK_RESPONSE_CANCEL,
 					NULL);
   hbox = gtk_hbox_new (FALSE, 0);
